==> yos.core-2.2.4-sources.jar: restcontroller/system/tools.java <==
package restcontroller.system;

import beans.parameter.Parameter;
import com.alibaba.fastjson.JSONObject;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.annotation.CACHEING;
import common.data.QuerySQL;
import common.data.Row;
import common.data.Rows;
import common.data.RowsMap;
import restcontroller.R;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;

@API(title = "行政区域查询")
public class tools extends Controller {
    public tools(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "省份查询", accesstoken = false, apiversion = R.ID10002801.v1.class)
    @CACHEING(life = 3600)
    public String query_arealist() throws YosException {
        Rows provincerows = dbConnect.runSqlQuery("select provinceid,province from  t_province order by provinceid");
        RowsMap cityrowsMap = dbConnect.runSqlQuery("select cityid,city,provinceid from t_city order by cityid").toRowsMap("provinceid");
        RowsMap countyrowsMap = dbConnect.runSqlQuery("select countyid,county,cityid from t_county order by countyid").toRowsMap("cityid");

        JSONObject provinceObject = new JSONObject(true);
        for (Row provincerow : provincerows) {
            JSONObject cityObject = new JSONObject(true);
            for (Row cityrow : cityrowsMap.get(provincerow.getString("provinceid"))) {
                ArrayList<String> countylist = countyrowsMap.get(cityrow.getString("cityid")).toArrayList("county");
                if (countylist.isEmpty()) {
                    countylist.add("市辖区");
                }
                cityObject.put(cityrow.getString("city"), countylist);
            }
            provinceObject.put(provincerow.getString("province"), cityObject);
        }
        return getSucReturnObject().setData(provinceObject).toString();
    }

    @API(title = "前端日志记录", accesstoken = false, apiversion = R.ID10022501.v1.class)
    public String saveWebClientErrLog() throws YosException {
        if ("true".equals(Parameter.get("system_client_logsave"))) {
            String keyname = content.getString("keyname");
            String log = content.getString("log");
            dbConnect.runSqlUpdate("insert into sys_log(logid,type,keyname,msg,createtime) values(" + createTableID("sys_log") + ",'前端','" + keyname + "','" + log + "',now())");
        }
        return getSucReturnObject().toString();
    }

    @API(title = "根据rowindex查询指定的字段值", apiversion = R.ID10002901.v1.class)
    public String querylistdatabyrowindex() throws YosException {
        int rowindex = content.getIntValue("rowindex");
        String listqueryid = content.getStringValue("listqueryid");
        String fieldname = content.getStringValue("fieldname");

        JSONObject object = new JSONObject();
        if (QuerySQL.QuerySQLMap.containsKey(listqueryid)) {
            object = querylistdatabyrowindex_get(listqueryid, fieldname, rowindex);
            querylistdatabyrowindex_preload(listqueryid, fieldname, rowindex);
        }
        return getSucReturnObject().setData(object).toString();
    }

    private static HashMap<String, JSONObject> map = new HashMap<>();
    private static int day = 0;

    /**
     * 预加载前后各5条
     *
     * @param listqueryid
     * @param fieldname
     * @param rowindex
     */
    private void querylistdatabyrowindex_preload(String listqueryid, String fieldname, int rowindex) {
        int today = Calendar.getInstance().get(Calendar.DATE);
        if (day != today) {
            map.clear();
            day = today;
        }
        new Thread() {
            @Override
            public void run() {
                super.run();
                for (int i = ((rowindex - 2) > 0 ? (rowindex - 2) : 1); i <= rowindex + 2; i++) {
                    querylistdatabyrowindex_get(listqueryid, fieldname, i);
                }
            }
        }.start();
    }

    public JSONObject querylistdatabyrowindex_get(String listqueryid, String fieldname, int rowindex) {
        String mapkey = listqueryid + "_" + fieldname + "_" + rowindex;
        if (!map.containsKey(mapkey)) {
            try {
                JSONObject object = new JSONObject();
                QuerySQL querySQL = QuerySQL.QuerySQLMap.get(listqueryid).clone().setPage(1, rowindex);
                Rows rows = querySQL.query(rowindex);
                if (rows.isNotEmpty()) {
                    long totalrows = rows.getTotalRows();
                    int pagesize = querySQL.pageSize_s;
                    if (fieldname.equals("")) {
                        object.put("data", rows.get(0).getLong(querySQL.uniquecolumnname));
                    } else {
                        object.put("data", rows.get(0).get(fieldname));
                    }
                    object.put("pageNumber", (rowindex + pagesize - 1) / pagesize);
                    object.put("pageSize", pagesize);
                    object.put("total", totalrows);
                    object.put("pageTotal", (totalrows + pagesize - 1) / pagesize);
                }
                map.put(mapkey, object);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return map.get(mapkey);
    }
}

==> yos.core-2.4.1-sources.jar: restcontroller/system/tools.java <==
package restcontroller.system;

import beans.parameter.Parameter;
import com.alibaba.fastjson.JSONObject;
import common.Controller;
import common.YosException;
import common.annotation.API;
import common.annotation.CACHEING;
import common.data.QuerySQL;
import common.data.Row;
import common.data.Rows;
import common.data.RowsMap;
import restcontroller.R;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;

@API(title = "行政区域查询")
public class tools extends Controller {
    public tools(JSONObject content) throws YosException {
        super(content);
    }

    @API(title = "省份查询", accesstoken = false, apiversion = R.ID10002801.v1.class)
    @CACHEING(life = 3600)
    public String query_arealist() throws YosException {
        Rows provincerows = dbConnect.runSqlQuery("select provinceid,province from  t_province order by provinceid");
        RowsMap cityrowsMap = dbConnect.runSqlQuery("select cityid,city,provinceid from t_city order by cityid").toRowsMap("provinceid");
        RowsMap countyrowsMap = dbConnect.runSqlQuery("select countyid,county,cityid from t_county order by countyid").toRowsMap("cityid");

        JSONObject provinceObject = new JSONObject(true);
        for (Row provincerow : provincerows) {
            JSONObject cityObject = new JSONObject(true);
            for (Row cityrow : cityrowsMap.get(provincerow.getString("provinceid"))) {
                ArrayList<String> countylist = countyrowsMap.get(cityrow.getString("cityid")).toArrayList("county");
                if (countylist.isEmpty()) {
                    countylist.add("市辖区");
                }
                cityObject.put(cityrow.getString("city"), countylist);
            }
            provinceObject.put(provincerow.getString("province"), cityObject);
        }
        return getSucReturnObject().setData(provinceObject).toString();
    }

    @API(title = "前端日志记录", accesstoken = false, apiversion = R.ID10022501.v1.class)
    public String saveWebClientErrLog() throws YosException {
        if ("true".equals(Parameter.get("system_client_logsave"))) {
            String keyname = content.getString("keyname");
            String log = content.getString("log");
            dbConnect.runSqlUpdate("insert into sys_log(logid,type,keyname,msg,createtime) values(" + createTableID("sys_log") + ",'前端','" + keyname + "','" + log + "',now())");
        }
        return getSucReturnObject().toString();
    }

    @API(title = "根据rowindex查询指定的字段值", apiversion = R.ID10002901.v1.class)
    public String querylistdatabyrowindex() throws YosException {
        int rowindex = content.getIntValue("rowindex");
        String listqueryid = content.getStringValue("listqueryid");
        String fieldname = content.getStringValue("fieldname");

        JSONObject object = new JSONObject();
        if (QuerySQL.QuerySQLMap.containsKey(listqueryid)) {
            object = querylistdatabyrowindex_get(listqueryid, fieldname, rowindex);
            querylistdatabyrowindex_preload(listqueryid, fieldname, rowindex);
        }
        return getSucReturnObject().setData(object).toString();
    }

    private static HashMap<String, JSONObject> map = new HashMap<>();
    private static int day = 0;

    /**
     * 预加载前后各5条
     *
     * @param listqueryid
     * @param fieldname
     * @param rowindex
     */
    private void querylistdatabyrowindex_preload(String listqueryid, String fieldname, int rowindex) {
        int today = Calendar.getInstance().get(Calendar.DATE);
        if (day != today) {
            map.clear();
            day = today;
        }
        new Thread() {
            @Override
            public void run() {
                super.run();
                for (int i = ((rowindex - 2) > 0 ? (rowindex - 2) : 1); i <= rowindex + 2; i++) {
                    querylistdatabyrowindex_get(listqueryid, fieldname, i);
                }
            }
        }.start();
    }

    public JSONObject querylistdatabyrowindex_get(String listqueryid, String fieldname, int rowindex) {
        String mapkey = listqueryid + "_" + fieldname + "_" + rowindex;
        if (!map.containsKey(mapkey)) {
            try {
                JSONObject object = new JSONObject();
                QuerySQL querySQL = QuerySQL.QuerySQLMap.get(listqueryid).clone().setPage(1, rowindex);
                Rows rows = querySQL.query(rowindex);
                if (rows.isNotEmpty()) {
                    long totalrows = rows.getTotalRows();
                    int pagesize = querySQL.pageSize_s;
                    if (fieldname.equals("")) {
                        object.put("data", rows.get(0).getLong(querySQL.uniquecolumnname));
                    } else {
                        object.put("data", rows.get(0).get(fieldname));
                    }
                    object.put("pageNumber", (rowindex + pagesize - 1) / pagesize);
                    object.put("pageSize", pagesize);
                    object.put("total", totalrows);
                    object.put("pageTotal", (totalrows + pagesize - 1) / pagesize);
                }
                map.put(mapkey, object);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return map.get(mapkey);
    }

    @API(title = "创建一个数据id", apiversion = R.ID10025901.v1.class)
    public String createTableDataId() throws YosException {
        String tablename = content.getString("tablename");
        if (dbConnect.runSqlQuery("select * from sys_object where table_name='" + tablename + "'").isEmpty()) {
            return getErrReturnObject().setErrMsg("无效的表名").toString();
        }
        return getSucReturnObject().setData(createTableID(tablename)).toString();
    }
}
